@@ -296,12 +296,8 @@ sub append {
 
     $that = $env->find($that);
 
-    if ($that->isa("Devel::TypeCheck::Type::Var")) {
-	$that = $env->unify($that, $env->genOmicron());
-    }
-
     if ($that->is(Devel::TypeCheck::Type::VAR())) {
-	$that = $env->unify($that, $env->freshKappa());
+	$that = $env->unify($that, $env->freshKappa);
 	return undef if (!defined($that));
     }
 
@@ -317,7 +313,7 @@ sub append {
 		$ret = undef;
 	    }
 	} elsif ($that->is(Devel::TypeCheck::Type::K()) ||
-		 $that->is(Devel::TypeCheck::Type::Z())) {
+		 $that->is(Devel::TypeCheck::Type::CV())) {
 	    $ret = $env->unify($env->genOmicron($that), $root);
 	} else {
 	    confess("Unknown type in append");
@@ -343,7 +339,7 @@ sub append {
 		$ret = undef;
 	    }
 	} elsif ($that->is(Devel::TypeCheck::Type::K()) ||
-		 $that->is(Devel::TypeCheck::Type::Z())) {
+		 $that->is(Devel::TypeCheck::Type::CV())) {
 	    $ret = $env->genOmicronTuple((@{$this->ary}, $that));
 	} else {
 	    confess("Unknown type in append");
